@@ -1,11 +1,13 @@
+## ------------------------------------------------------------------------
+n <- 5
+x <- rexp(n)
+
 ## ---- echo=TRUE----------------------------------------------------------
 a <- 0.8
-n = 5
 sigma <- (cos(pi*a/2))^(1/a)
 z <- stabledist::rstable(n = n, alpha = a, beta = 1, gamma = sigma, delta = 0, pm = 1)
 
 ## ------------------------------------------------------------------------
-x <- rexp(n)
 y <- x^(1/a) * z
 y
 
